==> billiards-0.1.tar.gz: billiards-0.1/scripts/pages/stylesheet.lua <==
-- Copyright (C) 2008 Papavasileiou Dimitris                             
--                                                                      
-- This program is free software: you can redistribute it and/or modify 
-- it under the terms of the GNU General Public License as published by 
-- the Free Software Foundation, either version 3 of the License, or    
-- (at your option) any later version.                                  
--                                                                      
-- This program is distributed in the hope that it will be useful,      
-- but WITHOUT ANY WARRANTY; without even the implied warranty of       
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        
-- GNU General Public License for more details.                         
--                                                                      
-- You should have received a copy of the GNU General Public License    
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.


network.mime["/stylesheet"] = "text/css"
network.pages["/stylesheet"] = [[
body {
	color: #000000 ;
	background-color: #FFFFFF ;
	font-family: sans-serif ;
	text-align: justify ;
	margin-right: 20px ;
	margin-left: 20px ;
}

a:link {
	color: #000080 ;
	background-color: inherit ;
	text-decoration: none ;
}

a:visited {
	background-color: inherit ;
	text-decoration: none ;
}

a:link:hover, a:visited:hover {
	color: #000080 ;
	background-color: #E0E0FF ;
}

a:link:active, a:visited:active {
	color: #FF0000 ;
}

hr {
	border: 0 ;
	height: 1px ;
	color: #a0a0a0 ;
	background-color: #a0a0a0 ;
}

table {
   border-collapse: separate ;
   border-spacing: 0px 0px ;
   empty-cells: show
}

input.number {
   border-width: 1px;
   text-align : right ;
   background : #fafafa ;
}

input.text {
   border-width: 1 ;
   background : #fafafa ;
}

tr.even {
   background : #7a8b8b ;
}

tr.odd {
   background : #b4cdcd ;
}

td {
   vertical-align :top ;
   border-top : solid ;
   border-bottom : solid ;
   border-width : thin ;
   border-color : #ebebeb ;
   padding-top : 2pt ;
   padding-bottom : 2pt
}

th {
   border-top : solid ;
   border-bottom : solid ;
   border-width : thin ;
   color : #264343 ;
   border-color : #52868b
}
]]

==> billiards-0.2.tar.gz: billiards-0.2/scripts/pages/stylesheet.lua <==
/*
    Copyright (C) 2008 Papavasileiou Dimitris                             
                                                                     
    This program is free software: you can redistribute it and/or modify 
    it under the terms of the GNU General Public License as published by 
    the Free Software Foundation, either version 3 of the License, or    
    (at your option) any later version.                                  
    
    This program is distributed in the hope that it will be useful,      
    but WITHOUT ANY WARRANTY; without even the implied warranty of       
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        
    GNU General Public License for more details.                         
                                                                     
    You should have received a copy of the GNU General Public License    
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

body {
	color: #000000 ;
	background-color: #FFFFFF ;
	font-family: sans-serif ;
	text-align: justify ;
	margin-right: 20px ;
	margin-left: 20px ;
}

a:link {
	color: #000080 ;
	background-color: inherit ;
	text-decoration: none ;
}

a:visited {
	background-color: inherit ;
	text-decoration: none ;
}

a:link:hover, a:visited:hover {
	color: #000080 ;
	background-color: #E0E0FF ;
}

a:link:active, a:visited:active {
	color: #FF0000 ;
}

hr {
	border: 0 ;
	height: 1px ;
	color: #a0a0a0 ;
	background-color: #a0a0a0 ;
}

table {
   border-collapse: separate ;
   border-spacing: 0px 0px ;
   empty-cells: show
}

input.number {
   border-width: 1px;
   text-align : right ;
   background : #fafafa ;
}

input.text {
   border-width: 1 ;
   background : #fafafa ;
}

input.check {
   border-width: 1 ;
   background : #fafafa ;
}

tr.even {
   background : #7a8b8b ;
}

tr.odd {
   background : #b4cdcd ;
}

td {
   vertical-align :top ;
   border-top : solid ;
   border-bottom : solid ;
   border-width : thin ;
   border-color : #ebebeb ;
   padding-top : 2pt ;
   padding-bottom : 2pt
}

th {
   border-top : solid ;
   border-bottom : solid ;
   border-width : thin ;
   color : #264343 ;
   border-color : #52868b
}
